yakumo.keystone.v3.endpoint

Package yakumo :: Package keystone :: Package v3 :: Module endpoint |
[hide private]
[frames] | no frames]

# Module endpoint

source code

Resource class and its manager for endpoints in Identity V3 API

Classes | [hide private]
| Resource resource class for endpoints on Identity V3 API
| Manager manager class for endpoints on Identity V3 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v3``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('description', 'description', mapper.Noop
      ), ('interface', 'interface', mapper.Noop), ('url', 'url', mapper.Noop
      ), ('region', 'region_id', mapper.Resource('keystone.region')), ('serv
      ice', 'service_id', mapper.Resource('keystone.service')),]